@@ -1,7 +1,8 @@
 {-# LANGUAGE TypeFamilies #-}
-{-# OPTIONS_GHC -fno-warn-orphans #-}
+{-# OPTIONS_GHC -Wno-orphans #-}
 module Main (main) where
 
+import Common
 import Control.Applicative hiding (Const)
 import Data.Reify
 import System.CPUTime
@@ -12,11 +13,11 @@ data List a b = Nil | Cons a b
 
 
 instance MuRef [a] where
-  type DeRef [a] = List a 
+  type DeRef [a] = List a
 
   mapDeRef f (x:xs) = Cons x <$> f xs
   mapDeRef _ []     = pure Nil
-  
+
 instance Functor (List a) where
    fmap _ Nil = Nil
    fmap f (Cons a b) = Cons a (f b)
@@ -32,7 +33,7 @@ main = do
 
         -- now, some timings.
         ns <- sequence [ timeme n | n <- take 8 (iterate (*2) 1024) ]
-        print $ reverse $ take 4 $ reverse [ n2 / n1 | (n1,n2) <- zip ns (tail ns) ]
+        print $ reverse $ take 4 $ reverse [ n2 / n1 | (n1,n2) <- zip ns (tail_ ns) ]
 
 timeme :: Int -> IO Float
 timeme n = do
@@ -42,5 +43,5 @@ timeme n = do
         j <- getCPUTime
         let n' :: Float
             n' = fromIntegral ((j - i) `div` 1000000000)
-        putStrLn $ " ==> " ++ show (n' / 1000)   
+        putStrLn $ " ==> " ++ show (n' / 1000)
         return n'
